@@ -23,6 +23,7 @@ class QLabel;
 class KConfigDialogManager;
 class QStackedLayout;
 
+class CaptureAreaComboBox;
 class KSImageWidget;
 class ProgressButton;
 class SmartSpinBox;
@@ -50,6 +51,7 @@ Q_SIGNALS:
     void dragInitiated();
     void newScreenshotRequest(Spectacle::CaptureMode theCaptureMode, int theCaptureDelat, bool theIncludePointer, bool theIncludeDecorations);
     void screenshotCanceled();
+    void screenshotPixmapSet();
 
 public Q_SLOTS:
 
@@ -63,6 +65,7 @@ public Q_SLOTS:
 #ifdef KIMAGEANNOTATOR_FOUND
     void showAnnotator();
     void hideAnnotator();
+    QSize sizeHintWhenAnnotating();
 #endif
 
 private Q_SLOTS:
@@ -79,7 +82,7 @@ private:
     QVBoxLayout *mContentOptionsForm{nullptr};
     KSImageWidget *const mImageWidget;
     ProgressButton *mTakeScreenshotButton;
-    QComboBox *mCaptureArea{nullptr};
+    CaptureAreaComboBox *mCaptureArea{nullptr};
     SmartSpinBox *mDelayMsec{nullptr};
     QCheckBox *mCaptureOnClick{nullptr};
     QCheckBox *mMousePointer{nullptr};
